@@ -41,6 +41,7 @@ def model_dict_to_str(
     edgedb_conversion_map: T.Dict[str, T.Dict[str, str]],
     set_links_d: T.Dict[str, "Resolver"] = None,
     force_replace: bool = False,  # make this true for inserts
+    set_strs: T.List[str] = None,
 ) -> T.Tuple[str, T.Dict[str, T.Any]]:
     from .resolver import UpdateOperation
 
@@ -92,6 +93,8 @@ def model_dict_to_str(
                         f"already exists in variables {variables}."
                     )
                 variables[variable_name] = variable_value
+    if set_strs:
+        field_strs.extend(set_strs)
     s = f'{{ {", ".join(field_strs)} }}'
     return s, variables
 
@@ -647,14 +650,17 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         cls: T.Type[ThisNodeType],
         resolver: "ResolverType",
         update_d: dict,
+        set_strs: T.List[str] = None,
         set_links_d: T.Dict[str, "Resolver"] = None,
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
-    ) -> T.Optional[ThisNodeType]:
+        only_one: bool = True,
+    ) -> T.Optional[T.Union[ThisNodeType, T.List[ThisNodeType]]]:
         s, variables = model_dict_to_str(
             d=update_d,
             edgedb_conversion_map=cls._edgedb_conversion_map,
             set_links_d=set_links_d,
+            set_strs=set_strs,
         )
 
         resolver.validate_against_query_variables(variables)
@@ -676,23 +682,27 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
                 client=given_client or cls.db_client,
                 query_str=update_s,
                 variables=variables_to_use,
-                only_one=True,
+                only_one=only_one,
             )
         if not raw_d:
             raise NodeException(f"No update for {cls._model_name} was registered.")
         with safe_span(op=f"parse.{cls._model_name}"):
-            node = resolver.parse_nested_obj(raw_d)
-        return node
+            if only_one:
+                return resolver.parse_nested_obj(raw_d)
+            else:
+                return [resolver.parse_nested_obj(d) for d in raw_d]
 
     @classmethod
     async def update_from_patch(
         cls: T.Type[ThisNodeType],
         patch: PatchType,
         resolver_with_filter: "ResolverType",
+        set_strs: T.List[str] = None,
+        only_one: bool = True,
         update_last_updated: bool = False,
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
-    ) -> T.Optional[ThisNodeType]:
+    ) -> T.Optional[T.Union[ThisNodeType, T.List[ThisNodeType]]]:
         if update_last_updated:
             if is_unset(getattr(patch, "last_updated", None)):
                 patch.last_updated = datetime.now(tz=ZoneInfo("America/New_York"))
@@ -700,16 +710,18 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         set_links_d = make_set_links_d(model=patch, model_d=update_d)
         if not update_d and not set_links_d:
             raise NodeException("No update registered.")
-        node = await cls._update(
+        node_or_nodes = await cls._update(
             resolver=resolver_with_filter,
             update_d=update_d,
+            set_strs=set_strs,
             set_links_d=set_links_d,
             batch=batch,
             given_client=given_client,
+            only_one=only_one,
         )
         if batch:
             return None
-        return node
+        return node_or_nodes
 
     async def update(
         self,
